"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CmsEntryDataSource = void 0;
var _zod = _interopRequireDefault(require("zod"));
var _ModelGetQuery = require("./ModelGetQuery");
class CmsEntryDataSource {
  constructor(cms) {
    this.cms = cms;
  }
  getType() {
    return "cms.entry";
  }
  getConfigSchema() {
    return _zod.default.object({
      modelId: _zod.default.string(),
      entryId: _zod.default.string()
    });
  }
  async load(request) {
    const requestedPaths = request.getPaths();
    const queryPaths = !requestedPaths || requestedPaths.length === 0 ? ["id"] : requestedPaths;
    const config = request.getConfig();
    const schemaClient = await this.cms.getExecutableSchema("preview");
    const model = await this.cms.getModel(config.modelId);
    const listQuery = new _ModelGetQuery.ModelGetQuery();
    const query = listQuery.getQuery(model, queryPaths);
    const response = await schemaClient({
      query,
      operationName: "GetEntry",
      variables: {
        entryId: config.entryId
      }
    });

    // @ts-expect-error Naive return for the time being.
    return response.data.entry.data;
  }
}
exports.CmsEntryDataSource = CmsEntryDataSource;

//# sourceMappingURL=CmsEntryDataSource.js.map