"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SelectionFormatter = void 0;
class SelectionFormatter {
  /**
   * Converts a GraphQL selection object into a formatted GraphQL query string
   * @param selection GraphQL selection object
   * @param indent Indentation level
   * @returns Formatted GraphQL query string
   */
  formatSelection(selection, indent = 0) {
    const lines = ["{"];
    Object.entries(selection).forEach(([key, value]) => {
      if (value === true) {
        lines.push(key);
      } else if ("type" in value && "fields" in value) {
        // Handle fragment
        const fragment = value;
        lines.push(`... on ${fragment.type} ${this.formatSelection(fragment.fields, indent + 1)}`);
      } else {
        // Handle regular nested fields
        const fragments = Object.entries(value).filter(([k]) => k.startsWith("fragment_")).map(([, v]) => v);
        const regularFields = Object.entries(value).filter(([k]) => !k.startsWith("fragment_")).reduce((acc, [k, v]) => ({
          ...acc,
          [k]: v
        }), {});
        if (Object.keys(regularFields).length > 0) {
          lines.push(`${key} ${this.formatSelection(regularFields, indent + 1)}`);
        } else if (fragments.length > 0) {
          lines.push(`${key} {`);
          fragments.forEach(fragment => {
            lines.push(`... on ${fragment.type} ${this.formatSelection(fragment.fields, indent + 2)}`);
          });
          lines.push(`}`);
        }
      }
    });
    lines.push(`}`);
    return lines.join("\n");
  }
}
exports.SelectionFormatter = SelectionFormatter;

//# sourceMappingURL=SelectionFormatter.js.map